@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Aug 2002
 ;;;;
-;;;; $Id: base.lisp 7061 2003-09-07 06:34:45Z kevin $
+;;;; $Id: base.lisp 10302 2005-01-29 02:20:11Z kevin $
 ;;;;
 ;;;; This file, part of LML, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -253,7 +253,7 @@
 
 (defmacro page (out-file &body body)
   `(with-open-file (*html-output*
-		    (lml-file-name ,out-file :output)
+		    (lml-file-name ',out-file :output)
 		    :direction :output
 		    :if-exists :supersede)
      (xhtml-prologue)
