@@ -1,7 +1,7 @@
 #+cmu (setq ext:*gc-verbose* nil)
 
-(require :lml)
-(in-package :lml)
+(asdf:operate 'asdf:load-op 'lml)
+(in-package lml)
 (let ((cwd (parse-namestring (lml-cwd))))
   (process-dir cwd))
 (lml-quit)
