@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Aug 2002
 ;;;;
-;;;; $Id: stdsite.lisp 10302 2005-01-29 02:20:11Z kevin $
+;;;; $Id: stdsite.lisp 11291 2006-11-07 06:29:48Z kevin $
 ;;;;
 ;;;; This file, part of LML, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -56,7 +56,8 @@
 			(lml-load "contents.lml_"))
 		  (td :valign "top"
 		      ,@body
-		      (std-footer ,file)))))))
+		      (std-footer ,file)))))
+    (lml-load "final.lml_")))
   
 
 (defmacro print-std-page (file title &body body)
